/* $Id: Object.h,v 1.3 1999/11/06 05:50:58 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(xarm_object_h)
#define xarm_object_h

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Registry.h>

class _ObjectClass : public DropSiteClass {
 protected:
   _ObjectClass() {} /* only a derived class can make this */

   virtual WidgetClass classPointer() { return objectClass; }
   virtual _XtString className() { return (_XtString) "Object"; }
 public:
   /* This is defined in BaseClass, but I put it here to follow the doc
      for Motif 1.2.  It actually just calls the one in BaseClass. */
   void destroyCallback(XtCallbackProc fp, XtPointer data = NULL)
                     {  WObjectClass::destroyCallback(fp, data); }  
};

#endif
